@@ -10,7 +10,7 @@ It union all project models.
 =cut
 
 package QBit::Application;
-$QBit::Application::VERSION = '0.010';
+$QBit::Application::VERSION = '0.011';
 use qbit;
 
 use base qw(QBit::Class);
@@ -193,7 +193,7 @@ sub get_option {
     my $res = $self->{'__OPTIONS__'}{$name} || return $default;
 
     foreach my $str (ref($res) eq 'ARRAY' ? @$res : $res) {
-        while ($str =~ /^(.*?)(?:\${([\w\d_]+)})(.*)$/) {
+        while ($str =~ /^(.*?)(?:\$\{([\w\d_]+)\})(.*)$/) {
             $str = ($1 || '') . ($self->get_option($2) || '') . ($3 || '');
         }
     }
